Models in PetroBuffer
=====================

Buffer Models
*************

Mineral buffer models recognised in PetroBuffer are:

**1. Frost:** (Frost, 1991), PetroBuffer's default buffer model. Covers QIF, IW, WM, IM, CoCoO, FMQ, NNO and MH.

**2. Campbell:** (Campbell et. al., 2009), provides high pressure calibrations for the IW and NNO buffers.

Ferric/Ferrous <-> fO2 interconversions
***************************************

**1. kc1991:** (Kress and Carmicheal, 1991), PetroBuffer's default conversion between fO2 and the speciation of iron in a melt.

**2. r2013:** (Righter et al., 2013), a high iron implementation suitable where the total Fe is higher than 15 wt%, e.g. for Martian melts.
